@@ -148,6 +148,7 @@ _records = [
     Country(u"Korea, Democratic People's Republic of", "KP", "PRK", "408",
             u"Korea, Democratic People's Republic of"),
     Country(u"Korea, Republic of", "KR", "KOR", "410", u"Korea, Republic of"),
+    Country(u"Kosovo", "XK", "XKX", "983", u"Kosovo"),
     Country(u"Kuwait", "KW", "KWT", "414", u"Kuwait"),
     Country(u"Kyrgyzstan", "KG", "KGZ", "417", u"Kyrgyzstan"),
     Country(u"Lao People's Democratic Republic", "LA", "LAO", "418",
@@ -161,8 +162,7 @@ _records = [
     Country(u"Lithuania", "LT", "LTU", "440", u"Lithuania"),
     Country(u"Luxembourg", "LU", "LUX", "442", u"Luxembourg"),
     Country(u"Macao", "MO", "MAC", "446", u"Macao"),
-    Country(u"Macedonia, the former Yugoslav Republic of", "MK", "MKD", "807",
-            u"Macedonia, the former Yugoslav Republic of"),
+    Country(u"North Macedonia", "MK", "MKD", "807", u"North Macedonia"),
     Country(u"Madagascar", "MG", "MDG", "450", u"Madagascar"),
     Country(u"Malawi", "MW", "MWI", "454", u"Malawi"),
     Country(u"Malaysia", "MY", "MYS", "458", u"Malaysia"),
@@ -262,7 +262,7 @@ _records = [
     Country(u"Suriname", "SR", "SUR", "740", u"Suriname"),
     Country(u"Svalbard and Jan Mayen", "SJ", "SJM", "744",
             u"Svalbard and Jan Mayen"),
-    Country(u"Swaziland", "SZ", "SWZ", "748", u"Swaziland"),
+    Country(u"Eswatini", "SZ", "SWZ", "748", u"Eswatini"),
     Country(u"Sweden", "SE", "SWE", "752", u"Sweden"),
     Country(u"Switzerland", "CH", "CHE", "756", u"Switzerland"),
     Country(u"Syrian Arab Republic", "SY", "SYR", "760",
@@ -292,7 +292,8 @@ _records = [
     Country(u"United Kingdom of Great Britain and Northern Ireland",
             "GB", "GBR", "826",
             u"United Kingdom of Great Britain and Northern Ireland"),
-    Country(u"United States", "US", "USA", "840", u"United States"),
+    Country(u"United States of America", "US", "USA", "840",
+            u"United States of America"),
     Country(u"United States Minor Outlying Islands", "UM", "UMI", "581",
             u"United States Minor Outlying Islands"),
     Country(u"Uruguay", "UY", "URY", "858", u"Uruguay"),
@@ -344,7 +345,7 @@ class _CountryLookup(object):
             k = key.upper()
             if len(k) == 2:
                 r = _by_alpha2.get(k, default)
-            elif len(k) == 3 and re.match(r"[0-9]{3}", k):
+            elif len(k) == 3 and re.match(r"[0-9]{3}", k) and k != "000":
                 r = _by_numeric.get(k, default)
             elif len(k) == 3:
                 r = _by_alpha3.get(k, default)
@@ -375,4 +376,5 @@ class _CountryLookup(object):
         except KeyError:
             return False
 
+
 countries = _CountryLookup()
